<?php
namespace TYPO3\TYPO3CR\Aspect;

/*                                                                        *
 * This script belongs to the TYPO3 Flow package "TYPO3CR".               *
 *                                                                        *
 * It is free software; you can redistribute it and/or modify it under    *
 * the terms of the GNU General Public License, either version 3 of the   *
 * License, or (at your option) any later version.                        *
 *                                                                        *
 * The TYPO3 project - inspiring people to share!                         *
 *                                                                        */

use TYPO3\Flow\Annotations as Flow;

/**
 * An aspect which centralizes the logging of node operations
 *
 * @Flow\Aspect
 * @Flow\Scope("singleton")
 */
class LoggingAspect {

	/**
	 * @var \TYPO3\Flow\Log\SystemLoggerInterface
	 * @Flow\Inject
	 */
	protected $systemLogger;

	/**
	 * Logs calls of remove()
	 *
	 * @Flow\AfterReturning("method(TYPO3\TYPO3CR\Domain\Model\NodeData->remove())")
	 * @param \TYPO3\Flow\Aop\JoinPointInterface $joinPoint The current joinpoint
	 * @return mixed The result of the target method if it has not been intercepted
	 */
	public function logRemove(\TYPO3\Flow\Aop\JoinPointInterface $joinPoint) {
		$nodeData = $joinPoint->getProxy();
		$this->systemLogger->log(sprintf('Removed node data "%s" from workspace "%s" (identifier: "%s")', $nodeData->getPath(), $nodeData->getWorkspace()->getName(), $nodeData->getIdentifier()), LOG_DEBUG);
	}

}
